Enum mml::pgp::NativePgpSecretKey
source · pub enum NativePgpSecretKey {
None,
Raw(SignedSecretKey),
Path(PathBuf),
Keyring(KeyringEntry),
}Available on crate features
pgp-native and pgp only.Expand description
The native PGP secret key source.
Variants
None
Raw(SignedSecretKey)
The native PGP secret key is given as it is (raw).
Path(PathBuf)
The native PGP secret key is located at the given path.
Keyring(KeyringEntry)
The native PGP secret key is located in the user’s global keyring at the given entry.
Implementations
sourceimpl NativePgpSecretKey
impl NativePgpSecretKey
pub async fn get(&self, recipient: impl ToString) -> Result<SignedSecretKey>